package com.goomood.phm.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.goomood.common.annotation.Log;
import com.goomood.common.core.controller.BaseController;
import com.goomood.common.core.domain.AjaxResult;
import com.goomood.common.enums.BusinessType;
import com.goomood.phm.domain.BasicDeviceType;
import com.goomood.phm.service.IBasicDeviceTypeService;
import com.goomood.common.utils.poi.ExcelUtil;

/**
 * 设备类型Controller
 * 
 * @author goomood
 * @date 2024-11-16
 */
@RestController
@RequestMapping("/basic/deviceType")
public class BasicDeviceTypeController extends BaseController
{
    @Autowired
    private IBasicDeviceTypeService basicDeviceTypeService;

    /**
     * 查询设备类型列表
     */
    @PreAuthorize("@ss.hasPermi('basic:deviceType:list')")
    @GetMapping("/list")
    public AjaxResult list(BasicDeviceType basicDeviceType)
    {
        List<BasicDeviceType> list = basicDeviceTypeService.selectBasicDeviceTypeList(basicDeviceType);
        return success(list);
    }

    /**
     * 导出设备类型列表
     */
    @PreAuthorize("@ss.hasPermi('basic:deviceType:export')")
    @Log(title = "设备类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BasicDeviceType basicDeviceType)
    {
        List<BasicDeviceType> list = basicDeviceTypeService.selectBasicDeviceTypeList(basicDeviceType);
        ExcelUtil<BasicDeviceType> util = new ExcelUtil<BasicDeviceType>(BasicDeviceType.class);
        util.exportExcel(response, list, "设备类型数据");
    }

    /**
     * 获取设备类型详细信息
     */
    @PreAuthorize("@ss.hasPermi('basic:deviceType:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(basicDeviceTypeService.selectBasicDeviceTypeById(id));
    }

    /**
     * 新增设备类型
     */
    @PreAuthorize("@ss.hasPermi('basic:deviceType:add')")
    @Log(title = "设备类型", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BasicDeviceType basicDeviceType)
    {
        return toAjax(basicDeviceTypeService.insertBasicDeviceType(basicDeviceType));
    }

    /**
     * 修改设备类型
     */
    @PreAuthorize("@ss.hasPermi('basic:deviceType:edit')")
    @Log(title = "设备类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BasicDeviceType basicDeviceType)
    {
        return toAjax(basicDeviceTypeService.updateBasicDeviceType(basicDeviceType));
    }

    /**
     * 删除设备类型
     */
    @PreAuthorize("@ss.hasPermi('basic:deviceType:remove')")
    @Log(title = "设备类型", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(basicDeviceTypeService.deleteBasicDeviceTypeByIds(ids));
    }
}
