package com.goomood.phm.service.impl;

import java.util.List;
import com.goomood.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goomood.phm.mapper.TechTypeMapper;
import com.goomood.phm.domain.TechType;
import com.goomood.phm.service.ITechTypeService;

/**
 * 资料类型Service业务层处理
 * 
 * @author goomood
 * @date 2024-11-16
 */
@Service
public class TechTypeServiceImpl implements ITechTypeService 
{
    @Autowired
    private TechTypeMapper techTypeMapper;

    /**
     * 查询资料类型
     * 
     * @param id 资料类型主键
     * @return 资料类型
     */
    @Override
    public TechType selectTechTypeById(Long id)
    {
        return techTypeMapper.selectTechTypeById(id);
    }

    /**
     * 查询资料类型列表
     * 
     * @param techType 资料类型
     * @return 资料类型
     */
    @Override
    public List<TechType> selectTechTypeList(TechType techType)
    {
        return techTypeMapper.selectTechTypeList(techType);
    }

    /**
     * 新增资料类型
     * 
     * @param techType 资料类型
     * @return 结果
     */
    @Override
    public int insertTechType(TechType techType)
    {
        techType.setCreateTime(DateUtils.getNowDate());
        return techTypeMapper.insertTechType(techType);
    }

    /**
     * 修改资料类型
     * 
     * @param techType 资料类型
     * @return 结果
     */
    @Override
    public int updateTechType(TechType techType)
    {
        techType.setUpdateTime(DateUtils.getNowDate());
        return techTypeMapper.updateTechType(techType);
    }

    /**
     * 批量删除资料类型
     * 
     * @param ids 需要删除的资料类型主键
     * @return 结果
     */
    @Override
    public int deleteTechTypeByIds(Long[] ids)
    {
        return techTypeMapper.deleteTechTypeByIds(ids);
    }

    /**
     * 删除资料类型信息
     * 
     * @param id 资料类型主键
     * @return 结果
     */
    @Override
    public int deleteTechTypeById(Long id)
    {
        return techTypeMapper.deleteTechTypeById(id);
    }
}
